import decimal

from django.conf import settings
from django import template
from django.contrib.humanize.templatetags.humanize import intcomma

from ..models import Branch


register = template.Library()


@register.simple_tag
def get_branches():
    return Branch.objects.all()


@register.filter
def currency(value, currency=None):
    try:
        currency = currency.iso_code
    except AttributeError:
        currency = getattr(settings, 'BASE_CURRENCY', 'EUR')

    dec = decimal.Decimal(value)
    tup = dec.as_tuple()
    delta = len(tup.digits) + tup.exponent
    digits = ''.join(str(d) for d in tup.digits)
    if delta <= 0:
        zeros = abs(tup.exponent) - len(tup.digits)
        value = '0.' + ('0' * zeros) + digits
    else:
        value = digits[:delta] + ('0' * tup.exponent) + '.' + digits[delta:]
    value = value.rstrip('0')
    if value[-1] == '.':
        value = value[:-1]
    if not currency or currency != 'BTC':
        value = '{0:.2f}'.format(float(value))
    if tup.sign:
        value = '-' + value

    return u'{0} {1}'.format(currency, intcomma(value))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-02 03:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account_keeping', '0003_auto_20171223_0356'),
    ]

    operations = [
        migrations.CreateModel(
            name='Branch',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, verbose_name='Name')),
                ('slug', models.SlugField(max_length=128, verbose_name='Slug')),
            ],
            options={
                'verbose_name_plural': 'Branches',
                'ordering': ['name'],
                'verbose_name': 'Branch',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-02 03:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


def get_or_create_branch(apps, schema_editor):
    Branch = apps.get_model('account_keeping', 'Branch')
    if Branch.objects.count() == 0:
        Branch.objects.create(name="Main", slug="main")


class Migration(migrations.Migration):

    dependencies = [
        ('account_keeping', '0004_branch'),
    ]

    operations = [
        migrations.RunPython(get_or_create_branch),
        migrations.AddField(
            model_name='account',
            name='branch',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='accounts', to='account_keeping.Branch', verbose_name='Branch'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='invoice',
            name='branch',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='invoices', to='account_keeping.Branch', verbose_name='Branch'),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.17 on 2019-01-02 11:14
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('currency_history', '0001_initial'),
        ('account_keeping', '0005_auto_20190102_0349'),
    ]

    operations = [
        migrations.AddField(
            model_name='branch',
            name='currency',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='branches', to='currency_history.Currency', verbose_name='Currency'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='branch',
            name='slug',
            field=models.SlugField(max_length=128, unique=True, verbose_name='Slug'),
        ),
    ]
